@@ -3,7 +3,7 @@
 
 """Šis ir testa skripts"""
 
-def paradit_listi(liste, limenis):
+def paradit_listi(liste, limenis = 0):
 
 	"""Funkcijas kaut ko dara, bet es aizmirsu ko"""
 
